#########################################################################
# Autoconf support for embedded text
# Copyright (C) 1997 Eleftherios Gkioulekas <lf@amath.washington.edu>
#  
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
########################################################################

# ------------------------------------------------------------------------
# This macro will make sure that the file txtc.pl is present and will
# export the symbols needed to use it in your Makefile.am
# In your configure.in file add:
#  LF_PROG_TXTC
# and in your Makefile.am add
#  whatever is needed
# which I will figure out another day
# ------------------------------------------------------------------------

AC_DEFUN(LF_PROG_TXTC,[
  dnl Look for perl
  AC_CHECK_PROGS(PERL, perl perl5, perl)

  dnl See whether txtc.am is present. If not install it
  AC_MSG_CHECKING([whether txtc.am is installed])
  if test -f 'txtc.am'
  then
    AC_MSG_RESULT(yes)
  else
    AC_MSG_RESULT(no)
    cp ${srcdir}/m4/txtc.am ${srcdir}/txtc.am
  fi
  
  dnl Set @TXTC_TARGET@
  txtc_target="${srcdir}/txtc.am"
  AC_SUBST_FILE(txtc_target)
   
  dnl See whether txtc.pl is present. If not install it
  AC_MSG_CHECKING([whether txtc.pl is installed])
  if test -f 'txtc.pl'
  then
    AC_MSG_RESULT(yes)
  else
    AC_MSG_RESULT(no)
    changequote()dnl
    sed 's/^X//' << 'SHAR_EOF' > 'txtc.pl' &&
X# Text compiler.
X# Copyright (C) 1997 Eleftherios Gkioulekas <lf@amath.washington.edu>
X#  
X# This program is free software; you can redistribute it and/or modify
X# it under the terms of the GNU General Public License as published by
X# the Free Software Foundation; either version 2 of the License, or
X# (at your option) any later version.
X# 
X# This program is distributed in the hope that it will be useful,
X# but WITHOUT ANY WARRANTY; without even the implied warranty of
X# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
X# GNU General Public License for more details.
X# 
X# You should have received a copy of the GNU General Public License
X# along with this program; if not, write to the Free Software
X# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
X# -----------------------------------------------------------------------------
X# Usage
X#  perl txtc.pl <C++ compiler> <object.o> file1.* file2.* file3.* .....
X#
X# Example:
X#  perl txtc.pl g++ foo.o file.tcl 
X# will create an object file that defines the following symbols:
X#  char *file_tcl[] = { "line1", "line2", ... , "last line", NULL };
X#  int file_tcl_length = number of lines  
X# You will need to accompany the object file with a header file that
X# contains the following declarations
X#  extern char *file_tcl[];
X#  extern int file_tcl_length;
X#
X# ============================================================================
X#
X# Parse the command line options
X#
X($cxx,$outfname,@files) = @ARGV;
X$prefix = $outfname;
Xdie "$outfname must be *.o file." unless $prefix =~ /\.o$/;
Xgrep(s/\.o$//g,$prefix);
X#
X# Set up the header file
X#
Xopen(HFILE,">${prefix}.cc") || die "open: ${prefix}.cc : $!";
Xprint HFILE <<"END";
X/* The following was automatically generated by the graces of the
X** txtc perl script written by Eleftherios Gkioulekas 
X*/
X#define NULL (char *) 0
XEND
X#
X# Now go and do every file
X#
Xforeach $file (@files)
X{
X #
X # Load the text file
X open(TFILE,$file) || die "open: $file : $!";
X @the_text_file = <TFILE>;
X close(TFILE);
X #
X # Clean it up
X chop(@the_text_file);                    # nuke newlines
X @the_text_file = ($file,@the_text_file); # prepend with the filename
X grep(s/(\\)\s+$/\\/g,@the_text_file);    # nuke whitespace after a final \
X grep(s/(\\)/\\\\/g,@the_text_file);      # escape the escapes
X grep(s/\"/\\\"/g,@the_text_file);        # escape the quotes
X $text_file_size = @the_text_file;        # get the script's size
X 
X # Truncate the filename
X $file_trunc = $file;   
X grep(s/\./_/g , $file_trunc);
X $file_trunc = qx/basename $file_trunc/;
X chop($file_trunc);
X #
X # Now make the in the script
X print HFILE <<"END";
Xint ${file_trunc}_length = ${text_file_size};
Xchar *${file_trunc}[] = {
XEND
X foreach $line (@the_text_file)
X {
X  print HFILE <<"END";
X   "$line",
XEND
X }
X print HFILE <<"END";
X   NULL };
XEND
X}
Xclose(HFILE);
Xsystem("$cxx -c ${prefix}.cc");
Xsystem("rm -f ${prefix}.cc");
SHAR_EOF
    : || echo 'restore of txtc.pl failed'
  fi
  changequote([,])dnl
  dnl Now export substitutions for your Makefile.am
  TXTC="${PERL} `pwd`/txtc.pl ${CXX} "
  AC_SUBST(TXTC)
])

